@@ -9,6 +9,7 @@ replacement <- function(name, env = as.environment(-1), target_value = get(name,
       environment(new_value)$`_f` <- trace_calls(environment(new_value)$`_f`, name)
     } else {
       new_value <- trace_calls(target_value, name)
+      attributes(body(new_value)) <- attributes(body(target_value))
     }
     attributes(new_value) <- attributes(target_value)
 
@@ -27,9 +28,9 @@ replacement <- function(name, env = as.environment(-1), target_value = get(name,
 }
 
 replace <- function(replacement) {
-  .Call(covr_reassign_function, replacement$name, replacement$env, replacement$target_value, replacement$new_value)
+  .Call(covr_reassign_function, replacement$target_value, replacement$new_value)
 }
 
 reset <- function(replacement) {
-  .Call(covr_reassign_function, replacement$name, replacement$env, replacement$target_value, replacement$orig_value)
+  .Call(covr_reassign_function, replacement$target_value, replacement$orig_value)
 }
