@@ -1,9 +1,7 @@
-context("summary_functions")
-
-test_that("Summary gives 40% coverage and three lines with zero coverage", {
-  cv <- package_coverage("TestSummary")
-  expect_equal(percent_coverage(cv), 40)
-  expect_equal(nrow(zero_coverage(cv)), 3)
+test_that("Summary gives 50% coverage and two lines with zero coverage", {
+  cv <- package_coverage(test_path("TestSummary"))
+  expect_equal(percent_coverage(cv), 50)
+  expect_equal(nrow(zero_coverage(cv)), 2)
 })
 
 test_that("percent_coverage", {
